package org.nosqlite4j.core.cli;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.StreamTokenizer;
import java.util.ArrayList;
import java.util.Vector;

import org.nosqlite4j.core.DBStats;
import org.nosqlite4j.core.ddl.CreateTable;
import org.nosqlite4j.core.ddl.ListTables;
import org.nosqlite4j.core.dml.FreeGet;
import org.nosqlite4j.core.dml.Put;

public class CommandLineImpl implements CommandLine.ICommand {

	/**
	 * Shows how to use the CommandLine class.
	 * 
	 * @param args
	 *            The command-line parameters
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		// This technique of reading from either
		// a script file or
		// from the console was 'borrowed' from BeanShell.
		Reader inputSrc = null;
		if (args.length > 0) {
			inputSrc = new BufferedReader(new FileReader(args[0]));
		} else {
			inputSrc = new InputStreamReader(System.in);
		}

		// initialize the command line object.
		CommandLine jr = new CommandLine();
		jr.setCommandLinePrompt("nosqlite4j--> ");
		jr.setCommandLineVersion("NoSQLite4j v.01\n");

		jr.assignClassToCommnd("Put", "org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("Get", "org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("FreeGet",
				"org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("Scan",
				"org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("Alter",
				"org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("Create",
				"org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("List",
				"org.nosqlite4j.core.cli.CommandLineImpl");
		jr.assignClassToCommnd("DBstats",
				"org.nosqlite4j.core.cli.CommandLineImpl");
		jr.init();

		if (args.length > 0) {
			jr.setIsInteractive(false);
		}

		// parse and execute commands.
		jr.parseStream(new StreamTokenizer(inputSrc));

		System.out.println("\nDone.");
	}

	/**
	 * This method is invoked when the FOO command is used.
	 */
	@SuppressWarnings("rawtypes")
	public boolean doIt(Vector v) {
		try {
			if (v.get(0).toString().equalsIgnoreCase("list")) {
				ListTables list = new ListTables();
				System.out.println(list.list());
			}

			else if (v.get(0).toString().equalsIgnoreCase("put")
					&& v.size() == 6) {
				/*
				 * System.out.println( "Enter Table Name" ); BufferedReader
				 * bufferRead = new BufferedReader(new
				 * InputStreamReader(System.in)); String table =
				 * bufferRead.readLine(); System.out.println(
				 * "Enter Column Family" ); BufferedReader bufferReadCF = new
				 * BufferedReader(new InputStreamReader(System.in)); String
				 * ColumnFamily = bufferReadCF.readLine(); System.out.println(
				 * "Enter Qualifier" ); BufferedReader bufferReadQ = new
				 * BufferedReader(new InputStreamReader(System.in)); String
				 * Qualifier = bufferReadQ.readLine(); System.out.println(
				 * "Enter Key" ); BufferedReader bufferReadKEY = new
				 * BufferedReader(new InputStreamReader(System.in)); String Key
				 * = bufferReadKEY.readLine();
				 * 
				 * System.out.println( "Enter Value" ); BufferedReader
				 * bufferReadValue = new BufferedReader(new
				 * InputStreamReader(System.in)); String Value =
				 * bufferReadValue.readLine();
				 */

				Put put = new Put(v.get(1).toString(), v.get(2).toString(), v
						.get(3).toString(), v.get(4).toString(), v.get(5)
						.toString());
				put.add();
				System.out.println("Added");

			} else if (v.get(0).toString().equalsIgnoreCase("create")) {
				/*
				 * System.out.println( "Enter Table Name" ); BufferedReader
				 * bufferRead = new BufferedReader(new
				 * InputStreamReader(System.in)); String table =
				 * bufferRead.readLine(); System.out.println(
				 * "Enter Number Column Family" );
				 * 
				 * BufferedReader bufferReadCF = new BufferedReader(new
				 * InputStreamReader(System.in)); String ColumnFamilyNo =
				 * bufferReadCF.readLine(); ArrayList<String > cf = new
				 * ArrayList<String>(); for(int i = 0; i <
				 * Integer.parseInt(ColumnFamilyNo); i++) { System.out.println(
				 * "Enter Column Family" );
				 * 
				 * BufferedReader bufferCF = new BufferedReader(new
				 * InputStreamReader(System.in)); String ColumnFamily =
				 * bufferCF.readLine(); cf.add(ColumnFamily); }
				 */
				ArrayList<String> nameOfColumnFamily = new ArrayList<String>();
				for (int i = 2; i < v.size(); i++) {
					nameOfColumnFamily.add(v.get(i).toString());

				}
				CreateTable put = new CreateTable(v.get(1).toString(),
						nameOfColumnFamily);
				put.createTable();
				System.out.println("Table Created");

			} else if (v.get(0).toString().equalsIgnoreCase("dbstats")) {
				DBStats table = new DBStats();
				System.out.println(table.getReport());
			} else if (v.get(0).toString().equalsIgnoreCase("freeget")) {
				/*
				 * System.out.println( "Enter Table Name" ); BufferedReader
				 * bufferRead = new BufferedReader(new
				 * InputStreamReader(System.in)); String table =
				 * bufferRead.readLine();
				 * 
				 * System.out.println( "Enter Column Family" );
				 * 
				 * BufferedReader bufferCF = new BufferedReader(new
				 * InputStreamReader(System.in)); String colfam =
				 * bufferCF.readLine();
				 * 
				 * System.out.println( "Enter Qualifier" );
				 * 
				 * BufferedReader bufferQualifier = new BufferedReader(new
				 * InputStreamReader(System.in)); String qualifier =
				 * bufferQualifier.readLine();
				 * 
				 * System.out.println( "Enter Regex" );
				 * 
				 * BufferedReader bufferRegex = new BufferedReader(new
				 * InputStreamReader(System.in)); String regex =
				 * bufferRegex.readLine();
				 * 
				 * System.out.println( "Enter Limit" );
				 * 
				 * BufferedReader bufferlim = new BufferedReader(new
				 * InputStreamReader(System.in)); int limit =
				 * Integer.parseInt(bufferlim.readLine());
				 */

				FreeGet get = new FreeGet(v.get(1).toString(), v.get(2)
						.toString(), v.get(3).toString());
				if (v.size() == 6)
					get.setLimit(Integer.parseInt(v.get(5).toString()));
				get.addQualifiers(v.get(4).toString());
				System.out.println(get.get());

			}

		} catch (Exception e) {

		}
		return true;

	}
}
