package org.nosqlite4j.core.dml;

import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

import org.json.JSONException;
import org.nosqlite4j.core.DBManager;

public class BulkLoad extends DBManager {
	private String path;
	private String TableName;
	private String delimiter;
	private ArrayList<String> ColumnFamily = new ArrayList<String>();
	private ArrayList<String> Qualifiers = new ArrayList<String>();

	public String getPath() {
		return path;
	}

	public BulkLoad(String inpath, String tablename, String delim) {
		this.path = inpath;
		this.setTableName(tablename);
		this.delimiter = delim;

	}

	public void addSchema(String columnfamily, String qualifier) {
		ColumnFamily.add(columnfamily);
		Qualifiers.add(qualifier);

	}

	public void load() throws IOException, NullPointerException, JSONException {
		long StartTime = System.currentTimeMillis();
		if (path == null || TableName == null || delimiter == null) {
			System.err.println("Path or Table or delimiter not initialized ");
		} else {

			FileInputStream fistream = new FileInputStream(path);
			DataInputStream in = new DataInputStream(fistream);
			BufferedReader br = new BufferedReader(new InputStreamReader(in));
			String strLine;
			Put table = new Put();
			while ((strLine = br.readLine()) != null) {
				String[] temp = strLine.split(delimiter);
				if (getColumn_Oriented().equalsIgnoreCase("true")
						&& (temp.length - 1) == ColumnFamily.size()
						&& ((temp.length - 1) == Qualifiers.size())) {
					for (int i = 1; i < temp.length; i++) {
						table.setTable(TableName);
						table.setColumnFamily(ColumnFamily.get(i - 1));
						table.setQualifier(Qualifiers.get(i - 1));
						table.setKey(temp[0]);
						table.setValue(temp[i]);
						table.add();

					}

				}

				else if (getColumn_Oriented().equalsIgnoreCase("false")
						&& Qualifiers.size() > 0) {
					ArrayList<String> arr = new ArrayList<String>();
					for (int i = 1; i < temp.length; i++) {
						arr.add(temp[i]);
					}
					Put bulk = new Put(TableName, ColumnFamily.get(0),
							Qualifiers.get(0), temp[0], arr);
					bulk.add();

				} else {
					System.err
							.println("Error: Number of columns don't match for"
									+ strLine);
					break;
				}
				long endTime = System.currentTimeMillis();
				System.out.println("Time Taken for Bulk loading : "
						+ (endTime - StartTime) + " ms");
			}
			in.close();
		}
	}

	public void setPath(String path) {
		this.path = path;
	}

	public String getTablename() {
		return TableName;
	}

	public String getDelimiter() {
		return delimiter;
	}

	public void setDelimiter(String delimiter) {
		this.delimiter = delimiter;
	}

	public String getTableName() {
		return TableName;
	}

	public void setTableName(String tableName) {
		TableName = tableName;
	}

}
